@@ -15,7 +15,8 @@ class PreRunEventData(BaseModel):
     images: Optional[List[Image]]
     imagesfile: Optional[str]
     model_name: str
-    model_type: str
+    prediction_type: str
+    model_format: str
     base_model_id: Optional[str]
     include_data: Optional[List[str]]
     exclude_classes: Optional[List[str]]
